@@ -12,7 +12,8 @@ import urllib.parse as path_encoder
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
 #API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
-API_GW = "https://csctis3kqa.execute-api.us-east-2.amazonaws.com/api/"
+#API_GW = "https://csctis3kqa.execute-api.us-east-2.amazonaws.com/api/"
+API_GW = "https://eq0awyoili.execute-api.cn-north-1.amazonaws.com.cn/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
